@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: http2
 version: 1.5.4
-id: http2-1.5.4-328e73d4110ea2a7bdc57af8b03bb3c5
-key: http2_10balJPIdy64E9R1Vluwox
+id: http2-1.5.4-82dccce60697e4ed1d56153dae3e45f1
+key: http2_2xVpEXWRpwJID0FYFQeHrL
 license: BSD3
 maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
 synopsis: HTTP/2.0 library including frames and HPACK
@@ -31,7 +31,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.5.4
-hs-libraries: HShttp2-1.5.4-10balJPIdy64E9R1Vluwox
+hs-libraries: HShttp2-1.5.4-2xVpEXWRpwJID0FYFQeHrL
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
